@@ -1,4 +1,4 @@
-from abc import ABC
+from abc import ABC, abstractmethod
 from typing import Any, List, Dict, Union
 
 from . import api
@@ -78,17 +78,44 @@ class Message(RawMessage, Requestable, ABC):
     def ctx(self) -> Context:
         return self._ctx
 
-    async def add_reaction(self):
+    @abstractmethod
+    async def add_reaction(self, emoji: str):
+        """add emoji to msg's reaction list
 
+        https://developer.kaiheila.cn/doc/http/message#%E7%BB%99%E6%9F%90%E4%B8%AA%E6%B6%88%E6%81%AF%E6%B7%BB%E5%8A%A0%E5%9B%9E%E5%BA%94
 
-    async def reply(self, content: Union[str, List] = '', use_quote: bool = True, **kwargs):
+        https://developer.kaiheila.cn/doc/http/direct-message#%E7%BB%99%E6%9F%90%E4%B8%AA%E6%B6%88%E6%81%AF%E6%B7%BB%E5%8A%A0%E5%9B%9E%E5%BA%94
+
+        :param emoji: 😘
+        """
+        ...
+
+    @abstractmethod
+    async def delete_reaction(self, emoji: str, user: User):
+        """delete emoji from msg's reaction list
+
+        https://developer.kaiheila.cn/doc/http/message#%E5%88%A0%E9%99%A4%E6%B6%88%E6%81%AF%E7%9A%84%E6%9F%90%E4%B8%AA%E5%9B%9E%E5%BA%94
+
+        https://developer.kaiheila.cn/doc/http/direct-message#%E5%88%A0%E9%99%A4%E6%B6%88%E6%81%AF%E7%9A%84%E6%9F%90%E4%B8%AA%E5%9B%9E%E5%BA%94
+
+        :param emoji: 😘
+        :param user: whose reaction, delete others added reaction requires channel msg admin permission
+        """
+        ...
+
+    async def reply(self,
+                    content: Union[str, List] = '',
+                    use_quote: bool = True,
+                    *,
+                    type: MessageTypes = None,
+                    **kwargs):
         """
         reply to a msg, content can also be a card
         """
         if use_quote:
             kwargs['quote'] = self.id
 
-        return await self.ctx.channel.send(content, **kwargs)
+        return await self.ctx.channel.send(content, type=type, **kwargs)
 
     async def delete(self):
         return await self.gate.exec_req(api.Message.delete(msg_id=self.id))
@@ -132,8 +159,25 @@ class PublicMessage(Message):
     def mention_here(self) -> bool:
         return self.extra['mention_here']
 
-    async def reply(self, content: Union[str, List] = '', use_quote: bool = True, is_temp: bool = False, **kwargs):
-        return await super().reply(content, use_quote, temp_target_id=self.author_id if is_temp else '', **kwargs)
+    async def add_reaction(self, emoji: str):
+        return await self.gate.exec_req(api.Message.addReaction(msg_id=self.id, emoji=emoji))
+
+    async def delete_reaction(self, emoji: str, user: User = None):
+        req = api.Message.deleteReaction(msg_id=self.id, emoji=emoji, user_id=user.id if user else '')
+        return await self.gate.exec_req(req)
+
+    async def reply(self,
+                    content: Union[str, List] = '',
+                    use_quote: bool = True,
+                    is_temp: bool = False,
+                    *,
+                    type: MessageTypes = None,
+                    **kwargs):
+        return await super().reply(content,
+                                   use_quote,
+                                   temp_target_id=self.author_id if is_temp else '',
+                                   type=type,
+                                   **kwargs)
 
 
 class PrivateMessage(Message):
@@ -154,6 +198,13 @@ class PrivateMessage(Message):
     def channel(self) -> PrivateChannel:
         return self._channel
 
+    async def add_reaction(self, emoji: str):
+        return await self.gate.exec_req(api.DirectMessage.addReaction(msg_id=self.id, emoji=emoji))
+
+    async def delete_reaction(self, emoji: str, user: User = None):
+        req = api.DirectMessage.deleteReaction(msg_id=self.id, emoji=emoji, user_id=user.id if user else '')
+        return await self.gate.exec_req(req)
+
 
 class Event(RawMessage):
 
